"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const util_1 = require("util");
const core = __importStar(require("./core"));
const streaming = __importStar(require("./streaming"));
const logger_1 = require("./logger");
// Promise-friendly core fns
const writeFile = util_1.promisify(fs_1.default.writeFile);
// Create a child logger scoped to the module
const log = logger_1.logger.child({ module: 'run' });
/** Code backing the "run" CLI command */
async function main(rootURL, opts) {
    // Run the core functionality
    const { results, state } = await core.runCore(rootURL, opts);
    // Write reports and state
    // Generate some sort of id for the run
    const runId = Date.now();
    const reportFileName = `report-${runId}.json`;
    const stateFileName = `state-${runId}.json`;
    // Write report
    await writeFile(reportFileName, JSON.stringify(results, null, 2), 'utf8');
    log.info(`Wrote ${reportFileName}`);
    streaming.sendWroteReportFile(reportFileName, opts.streaming);
    await writeFile(stateFileName, JSON.stringify(state, null, 2), 'utf8');
    log.info(`Wrote ${stateFileName}`);
    streaming.sendWroteStateFile(stateFileName, opts.streaming);
}
// TODO: Accept multiple roots in the future
function cliEntry(rootHref, opts) {
    // Whether to output a results stream under resultsLog
    const { ci } = opts, options = __rest(opts, ["ci"]);
    // Read the url as the first CLI argument
    let rootURL;
    try {
        rootURL = new URL(rootHref);
    }
    catch (err) {
        log.fatal('The URL you provided was in an unexpected format: ', err.toString());
        process.exit(1);
    }
    main(rootURL, options).catch(err => {
        // TODO: Consider other ways of reporting errors here
        log.fatal('The process encountered an unrecoverable error: ', err);
        process.exit(1);
    });
}
exports.cliEntry = cliEntry;
//# sourceMappingURL=run.js.map